@@ -44,6 +44,22 @@ class Message:
             return False
         else:
             return bool(self.data.get('is_bot'))
+    @property
+    def url_ava(self):
+        """Ссылка на аватарку пользователя."""
+        url_builder = self.data.get('avatar_url', f'/avatar/{self.username}')
+        return f'https://florestmsgs-florestdev4185.amvera.io{url_builder}'
+    def download_ava(self):
+        """Вернет аватарку пользователя в bytes."""
+        try:
+            return requests.get(self.url_ava).content
+        except:
+            return
+    @property
+    def reply_to(self):
+        """Возвращает ID сообщения, на которое был сделан ответ со стороны пользователя.\nNone, если сообщение не является ответным на чужое."""
+        if self.data.get("reply_to"):
+            return int(self.data.get('reply_to'))
     
 class Post:
     def __init__(self, post: dict[str, str]):
@@ -139,6 +155,28 @@ class Bot:
                 return False
         else:
             return True
+    def send_reply(self, message, content: str) -> bool:
+        """Функция для ответа на чужое сообщение в мессенджере.\nmessage: экземпляр класса "Message", или ID сообщения (int).\ncontent: сообщение; как надо ответить на запрос.\nВозвращает True/False."""
+        if isinstance(message, int):
+            r = requests.post("https://florestmsgs-florestdev4185.amvera.io/api/bot/send_reply", params={"reply_to":message, "content":content}, proxies=self.proxies, headers={"X-Bot-Token":self.token})
+            if r.status_code != 200:
+                if self.raise_on_status_code:
+                    raise Exception(f"ОШИБКА! КОД: {r.status_code}. JSON: {r.json()}. ПРОВЕРЬТЕ ТОКЕН И ПРАВИЛЬНОСТЬ УКАЗАННЫХ ПАРАМЕТРОВ!!!")
+                else:
+                    return False
+            else:
+                return True
+        elif isinstance(message, Message):
+            r = requests.post("https://florestmsgs-florestdev4185.amvera.io/api/bot/send_reply", params={"reply_to":message.id, "content":content}, proxies=self.proxies, headers={"X-Bot-Token":self.token})
+            if r.status_code != 200:
+                if self.raise_on_status_code:
+                    raise Exception(f"ОШИБКА! КОД: {r.status_code}. JSON: {r.json()}. ПРОВЕРЬТЕ ТОКЕН И ПРАВИЛЬНОСТЬ УКАЗАННЫХ ПАРАМЕТРОВ!!!")
+                else:
+                    return False
+            else:
+                return True
+        else:
+            raise Exception(f'Неизвестный тип данных в аргументе message. Только класс Message и int!')
     def get_blogs(self) -> list[Post]:
         """Список постов с `/blogs`."""
         r = requests.get("https://florestmsgs-florestdev4185.amvera.io/api/bot/get_blogs", headers={"X-Bot-Token":self.token}, proxies=self.proxies)
@@ -279,6 +317,45 @@ class AsyncBot:
             print(f"Ошибка клиента aiohttp: {e}")
             return False
 
+    async def send_reply(self, message, content: str) -> bool:
+        """Функция для ответа на чужое сообщение в мессенджере.\nmessage: экземпляр класса "Message", или ID сообщения (int).\ncontent: сообщение; как надо ответить на запрос.\nВозвращает True/False."""
+        if isinstance(message, int):
+            url = f"https://florestmsgs-florestdev4185.amvera.io/api/bot/send_reply"
+            params = {"reply_to":message, "content":content}
+            headers = {"X-Bot-Token": self.token}
+            try:
+                async with aiohttp.ClientSession() as session:
+                    async with session.post(url, params=params, proxy=self.proxies, headers=headers) as r:
+                        if r.status != 200:
+                            if self.raise_on_status_code:
+                                raise Exception(f"ОШИБКА! КОД: {r.status}. JSON: {await r.json()}. ПРОВЕРЬТЕ ТОКЕН И ПРАВИЛЬНОСТЬ УКАЗАННЫХ ПАРАМЕТРОВ!!!")
+                            else:
+                                return False
+                        else:
+                            return True
+            except aiohttp.ClientError as e:
+                print(f"Ошибка клиента aiohttp: {e}")
+                return False
+        elif isinstance(message, Message):
+            url = f"https://florestmsgs-florestdev4185.amvera.io/api/bot/send_reply"
+            params = {"reply_to":message.id, "content":content}
+            headers = {"X-Bot-Token": self.token}
+            try:
+                async with aiohttp.ClientSession() as session:
+                    async with session.post(url, params=params, proxy=self.proxies, headers=headers) as r:
+                        if r.status != 200:
+                            if self.raise_on_status_code:
+                                raise Exception(f"ОШИБКА! КОД: {r.status}. JSON: {await r.json()}. ПРОВЕРЬТЕ ТОКЕН И ПРАВИЛЬНОСТЬ УКАЗАННЫХ ПАРАМЕТРОВ!!!")
+                            else:
+                                return False
+                        else:
+                            return True
+            except aiohttp.ClientError as e:
+                print(f"Ошибка клиента aiohttp: {e}")
+                return False
+        else:
+            raise Exception(f'Неизвестный тип данных в аргументе message. Только класс Message и int!')
+
     async def get_blogs(self) -> list[Post]:
         """Асинхронный список постов с `/blogs`."""
         url = f"https://florestmsgs-florestdev4185.amvera.io/api/bot/get_blogs"
